@@ -20,7 +20,6 @@ from scipy.interpolate import interp1d
 from scipy.signal import filtfilt
 from scipy.interpolate import BSpline
 from irtemp import centikelvin_to_celsius
-from data_encoding import final_result
 
 
 # Function to load the input file
@@ -435,7 +434,7 @@ def peak_detection(sample_temp, plate_temp, material):
 
 # Wrapping functions
 # Wrapping function to get the inflection point
-def inflection_temp(frames, n_rows, n_columns, path):
+def inflection_temp(frames, n_rows, n_columns):
     '''
     Function to obtain sample temperature and plate temperature
     in every frame of the video using edge detection.
@@ -444,15 +443,11 @@ def inflection_temp(frames, n_rows, n_columns, path):
     -----------
     frames : List
         An list containing an array for each frame
-        in the cropped video or just a single array
-        in case of an image.
+        in the video or just a single array in case of an image.
     n_rows: List
         Number of rows of sample
     n_columns: List
         Number of columns of sample
-    path : String
-        Path to the location to temporarily store neural
-        network input images.
 
     Returns
     --------
@@ -470,9 +465,6 @@ def inflection_temp(frames, n_rows, n_columns, path):
     m_df : Dataframe
         A dataframe containing row and column coordinates of each sample
         and its respective inflection point obtained.
-    result_df : Dataframe
-        Dataframe containing well number, predictions of noise net anf
-        inflection net and melting point.
 
     '''
 
@@ -499,9 +491,8 @@ def inflection_temp(frames, n_rows, n_columns, path):
     # p_peaks, p_infl = peak_detection(s_temp, p_temp, 'Plate')
     # # Use the function 'infection_point' to obtain melting point of samples
     # inf_temp = inflection_point(s_temp, p_temp, s_peaks, p_peaks)
-    result_df = final_result(s_temp, p_temp, path)
     # Creating a dataframe with row and column coordinates
     # of sample centroid and its melting temperature (Inflection point).
     m_df = pd.DataFrame({'Row': regprops[0].Row, 'Column': regprops[0].Column,
                         'Melting point': np.asarray(s_infl)[:,0]})
-    return sorted_regprops, s_temp, p_temp, s_infl, result_df
+    return sorted_regprops, s_temp, p_temp, s_infl, m_df
